Examples of aioodbc usage
=========================

Below is a list of examples from `aioodbc/examples
<https://github.com/aio-libs/aioodbc/tree/master/examples>`_

Every example is a correct tiny python program.

.. _aioodbc-examples-simple:

Basic Usage
-----------

Basic example, executes query that return important number 42.

.. literalinclude:: ../examples/example_simple.py

Example of query execution in connection pool.

.. literalinclude:: ../examples/example_pool.py

Example of using async context managers with Pool, Connection and Cursor
objects.

.. literalinclude:: ../examples/example_context_managers.py
